package com.ultraboodog.entity.mob;

import com.ultraboodog.entity.Entity;
import com.ultraboodog.entity.spawner.ParticleSpawner;
import com.ultraboodog.graphics.Sprite;

public class Mob extends Entity
{
	public Sprite sprite;
	
	protected enum Direction
	{
		UP, DOWN, LEFT, RIGHT
	}
	
	protected Direction dir;
	protected boolean moving = false;
	
	public void teleport(double x, double y)
	{
		this.x = x * 16;
		this.y = y * 16;
	}
	
	public void move(double xa, double ya)
	{
		if (xa != 0 && ya != 0)
		{
			move(xa, 0);
			move(0, ya);
			return;
		}

		level.add(new ParticleSpawner((int) x, (int) y, 44, 50, level));
		
		if (xa > 0) dir = Direction.RIGHT;
		if (xa < 0) dir = Direction.LEFT;
		if (ya > 0) dir = Direction.DOWN;
		if (ya < 0) dir = Direction.UP;
		
		while (xa != 0)
		{
			if (Math.abs(xa) > 1)
			{
				if (!collision(abs(xa), ya))
				{
					this.x += abs(xa);
				}
				xa -= abs(xa);
			} else
			{
				if (!collision(abs(xa), ya))
				{
					this.x += xa;
				}
				xa = 0;
			}
		}

		while (ya != 0)
		{
			if (Math.abs(ya) > 1)
			{
				if (!collision(xa, abs(ya)))
				{
					this.y += abs(ya);
				}
				ya -= abs(ya);
			} else
			{
				if (!collision(xa, abs(ya)))
				{
					this.y += ya;
				}
				ya = 0;
			}
		}
	}
	
	private double abs(double value)
	{
		if (value < 0) return -1;
		return 1;
	}
	
	public Sprite getSprite()
	{
		return sprite;
	}
	
	protected boolean collision(double xa, double ya)
	{
		boolean solid = false;
		for (int c = 0; c < 4; c++)
		{
			double xt = ((x + xa) - c % 2) / 16;
			double yt = ((y + ya) - c / 2) / 16;
			int ix = (int) Math.ceil(xt);
			int iy = (int) Math.ceil(yt);
			if (c % 2 == 0) ix = (int) Math.floor(xt);
			if (c / 2 == 0) iy = (int) Math.floor(yt);
			if (level.getTile(ix, iy).solid()) solid = true;
		}
		return solid;
	}
	
	protected boolean slowCollision(double xa, double ya)
	{
		boolean slow = false;
		for (int c = 0; c < 4; c++)
		{
			double xt = ((x + xa) - c % 2) / 16;
			double yt = ((y + ya) - c / 2) / 16;
			int ix = (int) Math.ceil(xt);
			int iy = (int) Math.ceil(yt);
			if (c % 2 == 0) ix = (int) Math.floor(xt);
			if (c / 2 == 0) iy = (int) Math.floor(yt);
			if (level.getTile(ix, iy).slow()) slow = true;
		}
		return slow;
	}
	
	protected boolean fastCollision(double xa, double ya)
	{
		boolean fast = false;
		for (int c = 0; c < 4; c++)
		{
			double xt = ((x + xa) - c % 2) / 16;
			double yt = ((y + ya) - c / 2) / 16;
			int ix = (int) Math.ceil(xt);
			int iy = (int) Math.ceil(yt);
			if (c % 2 == 0) ix = (int) Math.floor(xt);
			if (c / 2 == 0) iy = (int) Math.floor(yt);
			if (level.getTile(ix, iy).fast()) fast = true;
		}
		return fast;
	}
	
	public boolean advanceCollision(double xa, double ya)
	{
		boolean advance = false;
		for (int c = 0; c < 4; c++)
		{
			double xt = ((x + xa) - c % 2) / 16;
			double yt = ((y + ya) - c / 2) / 16;
			int ix = (int) Math.ceil(xt);
			int iy = (int) Math.ceil(yt);
			if (c % 2 == 0) ix = (int) Math.floor(xt);
			if (c / 2 == 0) iy = (int) Math.floor(yt);
			if (level.getTile(ix, iy).advance()) advance = true;
		}
		return advance;
	}
	
	public boolean teleportCollision(double xa, double ya)
	{
		boolean teleport = false;
		for (int c = 0; c < 4; c++)
		{
			double xt = ((x + xa) - c % 2) / 16;
			double yt = ((y + ya) - c / 2) / 16;
			int ix = (int) Math.ceil(xt);
			int iy = (int) Math.ceil(yt);
			if (c % 2 == 0) ix = (int) Math.floor(xt);
			if (c / 2 == 0) iy = (int) Math.floor(yt);
			if (level.getTile(ix, iy).teleport()) teleport = true;
		}
		return teleport;
	}
	
	public void update()
	{
	}
	
	public void render()
	{
	}
}
