package com.ultraboodog.entity.mob;

import java.util.List;

import com.ultraboodog.graphics.AnimatedSprite;
import com.ultraboodog.graphics.Screen;
import com.ultraboodog.graphics.SpriteSheet;
import com.ultraboodog.level.Node;
import com.ultraboodog.util.Vector2i;

public class SmartCrab extends Mob
{
	public AnimatedSprite smartCrabDown = new AnimatedSprite(SpriteSheet.smartCrabDown, 16, 16, 3, 8);
	public AnimatedSprite smartCrabUp = new AnimatedSprite(SpriteSheet.smartCrabUp, 16, 16, 3, 8);
	public AnimatedSprite smartCrabLeft = new AnimatedSprite(SpriteSheet.smartCrabLeft, 16, 16, 3, 8);
	public AnimatedSprite smartCrabRight = new AnimatedSprite(SpriteSheet.smartCrabRight, 16, 16, 3, 8);
	
	private AnimatedSprite animSprite = smartCrabDown;
	
	private double xa = 0, ya = 0;
	private List<Node> path = null;
	private int time = 0;

	private boolean walking = false;
	
	public SmartCrab(int x, int y)
	{
		this.x = x;
		this.y = y;
		sprite = animSprite.getSprite();
	}
	
	private void move()
	{
		if (walking) animSprite.update();
		else animSprite.setFrame(0);
		
		xa = 0;
		ya = 0;
		double speed = 0.5;
		int radius = 150;
		
		int px = (int) level.getPlayerAt(0).getX();
		int py = (int) level.getPlayerAt(0).getY();
		Vector2i start = new Vector2i((int) getX() >> 4, (int) getY() >> 4);
		Vector2i destination = new Vector2i(px >> 4, py >> 4);
		if (time % 1 == 0) path = level.findPath(start, destination);
		if (path != null)
		{
			if (path.size() > 0)
			{
				List<Player> players = level.getPlayers(this, radius);
				if (players.size() > 0)
				{
					Vector2i vec = path.get(path.size() - 1).tile;
					if (x < vec.getX() << 4) xa += speed;
					if (x > vec.getX() << 4) xa -= speed;
					if (y < vec.getY() << 4) ya += speed;
					if (y > vec.getY() << 4) ya -= speed;
				}
			}
		}
		
		if (xa != 0 || ya != 0)
		{
			move(xa, ya);
			walking = true;
		} else walking = false;
	}
	
	public void update()
	{
		time++;
		move();
		
		if (ya < 0)
		{
			dir = Direction.UP;
			animSprite = smartCrabUp;
		} else if (ya > 0)
		{
			dir = Direction.DOWN;
			animSprite = smartCrabDown;
		}
		
		if (xa < 0)
		{
			dir = Direction.LEFT;
			animSprite = smartCrabLeft;
		} else if (xa > 0)
		{
			dir = Direction.RIGHT;
			animSprite = smartCrabRight;
		}
	}
	
	public void render(Screen screen)
	{
		sprite = animSprite.getSprite();
		screen.renderMob((int) x, (int) y, this);
	}
}
