package com.ultraboodog.graphics;

import com.ultraboodog.entity.mob.Mob;
import com.ultraboodog.level.tile.Tile;

public class Screen
{
	public int width, height;
	public int[] pixels;
	
	public int xOffset, yOffset;
	
	public Screen(int width, int height)
	{
		this.width = width;
		this.height = height;
		pixels = new int[width * height];
	}
	
	public void clear()
	{
		for (int i = 0; i < pixels.length; i++)
			pixels[i] = 0;
	}
	
	public void renderSprite(int xp, int yp, Sprite sprite, boolean fixed)
	{
		if (fixed)
		{
			xp -= xOffset;
			yp -= yOffset;
		}
		
		for (int y = 0; y < sprite.getHeight(); y++)
		{
			int ya = y + yp;
			for (int x = 0; x < sprite.getWidth(); x++)
			{
				int xa = x + xp;
				if (xa < 0 || xa >= width || ya < 0 || ya >= height) continue;
				pixels[xa + ya * width] = sprite.pixels[x + y * sprite.getWidth()];
			}
		}
	}
	
	public void renderTile(int xp, int yp, Tile tile)
	{
		xp -= xOffset;
		yp -= yOffset;
		for (int y = 0; y < tile.sprite.SIZE; y++)
		{
			int ya = y + yp;
			for (int x = 0; x < tile.sprite.SIZE; x++)
			{
				int xa = x + xp;
				if (xa < -tile.sprite.SIZE || ya < 0 || xa >= width || ya >= height) break;
				if (xa < 0) xa = 0;
				pixels[xa + ya * width] = tile.sprite.pixels[x + y * tile.sprite.SIZE];
			}
		}
	}
	
	public void renderMob(int xp, int yp, Mob mob)
	{
		xp -= xOffset;
		yp -= yOffset;
		for (int y = 0; y < 16; y++)
		{
			int ya = y + yp;
			for (int x = 0; x < 16; x++)
			{
				int xa = x + xp;
				if (xa < -16 || xa >= width || ya < 0 || ya >= height) break;
				if (xa < 0) xa = 0;
				int col = mob.sprite.pixels[x + y * 16];
				if (col != 0xFFFF00FF) pixels[xa + ya * width] = col;
			}
		}
	}
	
	public void renderPlayer(int xp, int yp, Sprite sprite)
	{
		xp -= xOffset;
		yp -= yOffset;
		for (int y = 0; y < 16; y++)
		{
			int ya = y + yp;
			for (int x = 0; x < 16; x++)
			{
				int xa = x + xp;
				if (xa < -16 || xa >= width || ya < 0 || ya >= height) break;
				if (xa < 0) xa = 0;
				int col = sprite.pixels[x + y * 16];
				if (col != 0xFFFF00FF) pixels[xa + ya * width] = col;
			}
		}
	}
	
	public void setOffset(int xOffset, int yOffset)
	{
		this.xOffset = xOffset;
		this.yOffset = yOffset;
	}
}
