package com.ultraboodog.graphics;

public class Sprite
{
	public final int SIZE;
	private int x, y;
	private int width, height;
	public int[] pixels;
	protected SpriteSheet sheet;
	
	public static Sprite voidSprite = new Sprite(16, 0x19212B);
	public static Sprite grass = new Sprite(16, 0, 0, SpriteSheet.tiles);
	public static Sprite stone = new Sprite(16, 1, 0, SpriteSheet.tiles);
	public static Sprite sand = new Sprite(16, 2, 0, SpriteSheet.tiles);
	public static Sprite sandCoral = new Sprite(16, 3, 0, SpriteSheet.tiles);
	public static Sprite orangePlant = new Sprite(16, 4, 0, SpriteSheet.tiles);
	public static Sprite sinkHoleExit = new Sprite(16, 5, 0, SpriteSheet.tiles);
	public static Sprite shell = new Sprite(16, 6, 0, SpriteSheet.tiles);
	public static Sprite slowSand = new Sprite(16, 7, 0, SpriteSheet.tiles);
	public static Sprite blueShell = new Sprite(16, 8, 0, SpriteSheet.tiles);
	public static Sprite fastSand = new Sprite(16, 9, 0, SpriteSheet.tiles);
	public static Sprite teleportSand = new Sprite(16, 10, 0, SpriteSheet.tiles);
	public static Sprite sandWater = new Sprite(16, 11, 0, SpriteSheet.tiles);
	public static Sprite brightSand = new Sprite(16, 12, 0, SpriteSheet.tiles);
	
	public static Sprite particle_sand = new Sprite(2, 0xD8D58F);
	
	protected Sprite(SpriteSheet sheet, int width, int height)
	{
		SIZE = (width == height) ? width : -1;
		this.width = width;
		this.height = height;
		this.sheet = sheet;
	}
	
	public Sprite(int size, int x, int y, SpriteSheet sheet)
	{
		SIZE = size;
		pixels = new int[SIZE * SIZE];
		this.x = x * size;
		this.y = y * size;
		this.sheet = sheet;
		load();
	}
	
	public Sprite(int width, int height, int colour)
	{
		SIZE = (width == height) ? width : -1;
		this.width = width;
		this.height = height;
		pixels = new int[width * height];
		setColour(colour);
	}
	
	public Sprite(int size, int colour)
	{
		SIZE = size;
		pixels = new int[SIZE * SIZE];
		setColour(colour);
	}
	
	public Sprite(int[] pixels, int width, int height)
	{
		SIZE = (width == height) ? width : -1;
		this.width = width;
		this.height = height;
		this.pixels = pixels;
	}
	
	private void setColour(int colour)
	{
		for (int i = 0; i < SIZE * SIZE; i++)
			pixels[i] = colour;
	}
	
	public int getWidth()
	{
		return width;
	}
	
	public int getHeight()
	{
		return height;
	}
	
	public void load()
	{
		for (int y = 0; y < SIZE; y++)
		{
			for (int x = 0; x < SIZE; x++)
			{
				pixels[x + y * SIZE] = sheet.pixels[(x + this.x) + (y + this.y) * sheet.SIZE];
			}
		}
	}
}
