package com.ultraboodog.graphics;

import java.awt.image.BufferedImage;
import java.io.IOException;

import javax.imageio.ImageIO;

public class SpriteSheet
{
	private String path;
	public final int SIZE;
	public final int WIDTH, HEIGHT;
	public int[] pixels;

	public static SpriteSheet tiles = new SpriteSheet("/textures/sheets/tilesheet.png", 256);
	
	public static SpriteSheet playerScuba = new SpriteSheet("/textures/sheets/playerScuba.png", 64, 48);
	public static SpriteSheet playerScubaDown = new SpriteSheet(playerScuba, 0, 0, 1, 3, 16);
	public static SpriteSheet playerScubaUp = new SpriteSheet(playerScuba, 1, 0, 1, 3, 16);
	public static SpriteSheet playerScubaRight = new SpriteSheet(playerScuba, 2, 0, 1, 3, 16);
	public static SpriteSheet playerScubaLeft = new SpriteSheet(playerScuba, 3, 0, 1, 3, 16);
	
	public static SpriteSheet dumbCrab = new SpriteSheet("/textures/sheets/crab.png", 64, 48);
	public static SpriteSheet dumbCrabDown = new SpriteSheet(dumbCrab, 0, 0, 1, 3, 16);
	public static SpriteSheet dumbCrabUp = new SpriteSheet(dumbCrab, 1, 0, 1, 3, 16);
	public static SpriteSheet dumbCrabRight = new SpriteSheet(dumbCrab, 2, 0, 1, 3, 16);
	public static SpriteSheet dumbCrabLeft = new SpriteSheet(dumbCrab, 3, 0, 1, 3, 16);
	
	public static SpriteSheet smartCrab = new SpriteSheet("/textures/sheets/smartCrab.png", 64, 48);
	public static SpriteSheet smartCrabDown = new SpriteSheet(smartCrab, 0, 0, 1, 3, 16);
	public static SpriteSheet smartCrabUp = new SpriteSheet(smartCrab, 1, 0, 1, 3, 16);
	public static SpriteSheet smartCrabRight = new SpriteSheet(smartCrab, 2, 0, 1, 3, 16);
	public static SpriteSheet smartCrabLeft = new SpriteSheet(smartCrab, 3, 0, 1, 3, 16);

	public Sprite[] sprites;
	
	public SpriteSheet(SpriteSheet sheet, int x, int y, int width, int height, int spriteSize)
	{
		int xx = x * spriteSize;
		int yy = y * spriteSize;
		int w = width * spriteSize;
		int h = height * spriteSize;
		SIZE = (width == height) ? width : -1;
		WIDTH = w;
		HEIGHT = h;
		pixels = new int[w * h];
		for (int y0 = 0; y0 < h; y0++)
		{
			int yp = yy + y0;
			for (int x0 = 0; x0 < w; x0++)
			{
				int xp = xx + x0;
				pixels[x0 + y0 * w] = sheet.pixels[xp + yp * sheet.WIDTH];
			}
		}
		
		int frame = 0;
		sprites = new Sprite[width * height];
		for (int ya = 0; ya < height; ya++)
		{
			for (int xa = 0; xa < width; xa++)
			{
				int[] spritePixels = new int[spriteSize * spriteSize];
				for (int y0 = 0; y0 < spriteSize; y0++)
				{
					for (int x0 = 0; x0 < spriteSize; x0++)
					{
						spritePixels[x0 + y0 * spriteSize] = pixels[(x0 + xa * spriteSize) + (y0 + ya * spriteSize) * WIDTH];
					}
				}
				Sprite sprite = new Sprite(spritePixels, spriteSize, spriteSize);
				sprites[frame++] = sprite;
			}
		}
	}
	
	public SpriteSheet(String path, int size)
	{
		this.path = path;
		SIZE = size;
		WIDTH = size;
		HEIGHT = size;
		pixels = new int[SIZE * SIZE];
		load();
	}
	
	public SpriteSheet(String path, int width, int height)
	{
		this.path = path;
		SIZE = width;
		WIDTH = width;
		HEIGHT = height;
		pixels = new int[WIDTH * HEIGHT];
		load();
	}
	
	public Sprite[] getSprites()
	{
		return sprites;
	}
	
	private void load()
	{
		try
		{
			BufferedImage image = ImageIO.read(SpriteSheet.class.getResource(path));
			int w = image.getWidth();
			int h = image.getHeight();
			image.getRGB(0, 0, w, h, pixels, 0, w);
		} catch (IOException e)
		{
			e.printStackTrace();
		}
	}
}
